@@ -9,7 +9,7 @@
 import functools
 
 import numpy as np
-from scipy.ndimage.filters import uniform_filter
+from scipy.ndimage import uniform_filter
 
 from raytraverse import translate, io
 
@@ -111,7 +111,7 @@ class Mapper(object):
             uv coordinates
         """
         si = np.stack(np.unravel_index(idx, shape))
-        if jitter:
+        if jitter and self.jitterrate > 0:
             rng = ((1 - self.jitterrate)/2, (1 + self.jitterrate)/2)
             offset = np.random.default_rng().uniform(*rng, si.shape).T
         else:
