@@ -6,7 +6,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 # =======================================================================
 import numpy as np
-from raytraverse import translate
+from raytraverse import translate, io
 from raytraverse.sky import skycalc
 from raytraverse.formatter import RadianceFormatter as RadFmt
 
@@ -33,8 +33,8 @@ class SkyData(object):
     intersky: bool, optional
         include interreflection between ground and sky (mimics perezlum.cal,
         not present in gendaymtx)
-    skyres: float, optional
-        approximate square patch size in degrees
+    skyres: int, optional
+        resolution of sky patches (sqrt(patches / hemisphere))
     minalt: float, optional
         minimum solar altitude for daylight masking
     mindiff: float, optional
@@ -42,7 +42,8 @@ class SkyData(object):
     """
 
     def __init__(self, wea, loc=None, skyro=0.0, ground_fac=0.2, intersky=True,
-                 skyres=12.0, minalt=2.0, mindiff=5.0, mindir=0.0):
+                 skyres=15, minalt=2.0, mindiff=5.0, mindir=0.0):
+        #: sky patach resolution
         self.skyres = skyres
         self.intersky = intersky
         if wea is None:
@@ -68,19 +69,6 @@ class SkyData(object):
         self.skydata = wea
         self.mask = None
 
-    @property
-    def skyres(self):
-        return self._skyres
-
-    @property
-    def side(self):
-        return self._side
-
-    @skyres.setter
-    def skyres(self, s):
-        self._side = int(np.floor(90/s)*2)
-        self._skyres = s
-
     @property
     def skyro(self):
         """sky rotation (in degrees, ccw)"""
@@ -132,16 +120,16 @@ class SkyData(object):
                 md = md[daymask]
             if hasattr(td, "__len__"):
                 td = td[daymask]
-            smtx, grnd, sun = skycalc.sky_mtx(sxyz, dirdif, self.side, md=md,
+            smtx, grnd, sun = skycalc.sky_mtx(sxyz, dirdif, self.skyres, md=md,
                                               ground_fac=self.ground_fac, td=td,
                                               intersky=self.intersky)
             # ratio between actual solar disc and patch
-            omegar = np.square(0.2665 * np.pi * self.side / 180) * .5
+            omegar = np.square(0.2665 * np.pi * self.skyres / 180) * .5
             plum = sun[:, -1] * omegar
             sun = np.hstack((sun, plum[:, None]))
             smtx = np.hstack((smtx, grnd[:, None]))
         else:
-            smtx = np.ones((1, self.side**2+1))
+            smtx = np.ones((1, self.skyres**2+1))
             sun = np.array([[0, 0, 1, 0, 0]])
             daymask = np.array([True])
             skydata = np.array([[0, 0, 1, 0, 1]])
@@ -190,8 +178,7 @@ class SkyData(object):
                 rowlabel = result['rowlabel']
             except (ValueError, KeyError):
                 rowlabel = None
-            self._side = int(np.sqrt(smtx.shape[1] - 1))
-            self._skyres = 180 / self._side
+            self.skyres = int(np.sqrt(smtx.shape[1] - 1))
             return skydata, smtx, sun, daymask, rowlabel
 
     def format_skydata(self, dat):
@@ -208,11 +195,11 @@ class SkyData(object):
         md = None
         td = 10.9735311509
         rowlabel = None
-        if hasattr(dat, 'shape'):
+        if isinstance(dat, np.ndarray):
             skydat = dat
         else:
             try:
-                skydat = np.loadtxt(dat)
+                skydat = io.load_txt(dat)
             except ValueError:
                 if loc is None:
                     loc = skycalc.get_loc_epw(dat)
@@ -286,7 +273,7 @@ class SkyData(object):
 
     @property
     def smtx(self):
-        """shape (np.sum(daymask), side**2 + 1) coefficients for each sky
+        """shape (np.sum(daymask), skyres**2 + 1) coefficients for each sky
         patch each row is a timestep, coefficients exclude sun"""
         return self._smtx[self.mask]
 
@@ -304,7 +291,7 @@ class SkyData(object):
 
     @sunproxy.setter
     def sunproxy(self, sxyz):
-        self._sunproxy = translate.xyz2skybin(sxyz, self.side)
+        self._sunproxy = translate.xyz2skybin(sxyz, self.skyres)
 
     def smtx_patch_sun(self, includesky=True):
         """generate smtx with solar energy applied to proxy patch
@@ -362,8 +349,32 @@ class SkyData(object):
         j = np.searchsorted(self._maskindices, i)
         return j[self._maskindices[j] == i]
 
+    def radiance_sky_matrix(self, outf, fmt='float', sun=True, sky=True, ncomps=3):
+        if sun:
+            mtx = self.smtx_patch_sun(sky).T
+        else:
+            mtx = self.smtx
+        rows = mtx.shape[0]
+        cols = mtx.shape[1]
+        mtx = np.repeat(mtx, ncomps, 1)
+        header = (f"#?RADIANCE\n{self.header()}\n"
+                  f"NCOMP={ncomps}\nFORMAT={fmt}\nNROWS={rows}\n"
+                  f"NCOLS={cols}\n\n")
+        fmt = fmt.lower()[0]
+        if fmt in ['f', 'd']:
+            data = io.np2bytes(mtx, np.dtype(f"<{fmt}"))
+            f = open(outf, 'w')
+            f.write(header)
+            f.close()
+            f = open(outf, 'ab')
+            f.write(data)
+            f.close()
+        else:
+            np.savetxt(outf, mtx, fmt='%.8e', delimiter="\t", comments="",
+                       header=header)
+
     def sky_description(self, i, prefix="skydata", grid=False, sun=True,
-                        ground=True):
+                        ground=True, sunpatch=False):
         """generate radiance scene files to directly render sky data at index i
 
         Parameters
@@ -376,6 +387,10 @@ class SkyData(object):
             render sky patches with grid lines
         sun: bool, optional
             include sun source in rad file
+        ground: bool, optional
+            include ground source
+        sunpatch: bool, optional
+            include sun energy in sun_patch (sun should be false)
 
         Returns
         -------
@@ -408,9 +423,12 @@ class SkyData(object):
             f.write(RadFmt.get_sundef(self.sun[mi, 0:3], c))
         f.close()
         f = open(f"{outf}.cal", 'w')
-        f.write(f"side:{self.side};\n{translate.scbinscal}")
+        f.write(f"side:{self.skyres};\n{translate.scbinscal}")
         f.close()
-        data = self.smtx[mi]
+        if sunpatch:
+            data = self.smtx_patch_sun()[mi]
+        else:
+            data = self.smtx[mi]
         nrbins = data.size
         header = "1\n0 {} {}\n".format(nrbins - 1, nrbins)
         np.savetxt(f"{outf}.dat", data, delimiter="\n", header=header,
